TagLocate class

Constructors

TagLocate({required String epc, required String rssi, required int signalValue, required bool valid})
TagLocate.fromJson(String source)
factory
TagLocate.fromMap(Map<String, dynamic> json)
factory

Properties

epc String
final
hashCode int
The hash code for this object.
no setterinherited
rssi String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signalValue int
final
valid bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromDynamic(dynamic raw) TagLocate?